/**
 * Search Coumnic user
 *
 * @author Pierre Hubert
 */

import { Grid, Paper, TextField } from "@material-ui/core";
import React from "react";
import { AsyncWidget } from "../widgets/AsyncWidget";
import { PageTitle } from "../widgets/PageTitle";

export class SearchComunicUsersRoute extends React.Component<
	{},
	{ firstName: string; lastName: string; email: string }
> {
	constructor(p: any) {
		super(p);
		this.state = {
			firstName: "",
			lastName: "",
			email: "",
		};

		this.updateFirstName = this.updateFirstName.bind(this);
		this.updateLastName = this.updateLastName.bind(this);
		this.updateEmailAddress = this.updateEmailAddress.bind(this);
		this.performSearch = this.performSearch.bind(this);
		this.buildResults = this.buildResults.bind(this);
	}

	updateFirstName(e: React.ChangeEvent<HTMLInputElement>) {
		this.setState({
			firstName: e.target.value,
		});
	}

	updateLastName(e: React.ChangeEvent<HTMLInputElement>) {
		this.setState({
			lastName: e.target.value,
		});
	}

	updateEmailAddress(e: React.ChangeEvent<HTMLInputElement>) {
		this.setState({
			email: e.target.value,
		});
	}

	get canPerformSearch(): boolean {
		return (
			this.state.firstName.length > 2 ||
			this.state.lastName.length > 2 ||
			this.state.email.length > 4
		);
	}

	get searchKey(): string {
		return (
			this.state.firstName +
			"##" +
			this.state.lastName +
			"##" +
			this.state.email
		);
	}

	async performSearch() {}

	render() {
		return (
			<div>
				<PageTitle name="Search Comunic user" />

				{/* Filter users */}
				<Grid container spacing={3}>
					<Grid item xs={3}>
						<TextField
							label="First name"
							style={{ width: "100%" }}
							value={this.state.firstName}
							onChange={this.updateFirstName}
						/>
					</Grid>
					<Grid item xs={3}>
						<TextField
							label="Last name"
							style={{ width: "100%" }}
							value={this.state.lastName}
							onChange={this.updateLastName}
						/>
					</Grid>
					<Grid item xs={6}>
						<TextField
							label="Email address"
							style={{ width: "100%" }}
							type="email"
							value={this.state.email}
							onChange={this.updateEmailAddress}
						/>
					</Grid>
				</Grid>

				{/* Perform search & display results */}
				{this.canPerformSearch ? (
					<AsyncWidget
						load={this.performSearch}
						onBuild={this.buildResults}
						errorMessage="Failed to search users!"
						key={this.searchKey}
					/>
				) : (
					<div></div>
				)}
			</div>
		);
	}

	buildResults() {
		return <p>Results!!! {this.searchKey}</p>;
	}
}
